@@ -1,7 +1,9 @@
 """Entry point defined here."""
-from paystackapi.transaction import Transaction
 from paystackapi.customer import Customer
 from paystackapi.plan import Plan
+from paystackapi.subscription import Subscription
+from paystackapi.transaction import Transaction
+
 from paystackapi.base import PayStackBase
 
 
@@ -11,6 +13,7 @@ class Paystack(PayStackBase):
     def __init__(self, secret_key=None):
         """Instantiate Basic Classes to call here."""
         PayStackBase.__init__(self, secret_key=secret_key)
-        self.transaction = Transaction
         self.customer = Customer
         self.plan = Plan
+        self.subscription = Subscription
+        self.transaction = Transaction
